@@ -5,11 +5,11 @@ from yafowil.base import factory
 resourcedir = os.path.join(os.path.dirname(__file__), 'resources')
 js = [{
     'group': 'yafowil.widget.wysihtml5.dependencies',
-    'resource': 'wysihtml5/dist/wysihtml5-0.3.0.js',
+    'resource': 'wysihtml5/wysihtml5-0.3.0.js',
     'order': 21,
 }, {
     'group': 'yafowil.widget.wysihtml5.dependencies',
-    'resource': 'bootstrap-wysihtml5/src/bootstrap-wysihtml5.js',
+    'resource': 'bootstrap3-wysihtml5/bootstrap3-wysihtml5.js',
     'order': 22,
 }, {
     'group': 'yafowil.widget.wysihtml5.common',
@@ -18,16 +18,16 @@ js = [{
 }]
 css = [{
     'group': 'yafowil.widget.wysihtml5.dependencies',
-    'resource': 'bootstrap-wysihtml5/src/bootstrap-wysihtml5.css',
+    'resource': 'bootstrap3-wysihtml5/bootstrap-wysihtml5.css',
     'order': 21,
 }, {
     'group': 'yafowil.widget.wysihtml5.dependencies',
-    'resource': 'bootstrap-wysihtml5/lib/css/wysiwyg-color.css',
-    'order': 22,
+    'resource': 'bootstrap3-wysihtml5/wysiwyg-color.css',
+    'order': 21,
 }, {
     'group': 'yafowil.widget.wysihtml5.common',
     'resource': 'widget.css',
-    'order': 23,
+    'order': 22,
 }]
 
 
